# -*- coding: utf-8 -*-

"""Test Logos

Utilisation :
    créer les variables d'environnement: (indiquer les valeurs
    pour le serveur ScoDoc que vous voulez interroger)

    export SCODOC_URL="https://scodoc.xxx.net/"
    export SCODOC_USER="xxx"
    export SCODOC_PASSWD="xxx"
    export CHECK_CERTIFICATE=0 # ou 1 si serveur de production avec certif SSL valide

    (on peut aussi placer ces valeurs dans un fichier .env du répertoire tests/api).

    Lancer :
        pytest tests/api/test_api_formations.py
"""

import requests

from tests.api.setup_test_api import API_URL, CHECK_CERTIFICATE, api_headers
from tests.api.tools_test_api import verify_fields
from tests.api.tools_test_api import FORMATION_FIELDS, MODIMPL_FIELDS


def test_formations_ids(api_headers):
    """
    Route: /formations_ids
    """
    r = requests.get(
        API_URL + "/formations_ids",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    formations_ids = r.json()
    # Une liste non vide d'entiers
    assert isinstance(formations_ids, list)
    assert len(formations_ids) > 0
    assert all(isinstance(x, int) for x in formations_ids)


def test_formations_by_id(api_headers):
    """
    Route: /formation/<int:formation_id>
    """
    r = requests.get(
        API_URL + "/formation/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    formation = r.json()
    assert verify_fields(formation, FORMATION_FIELDS) is True
    # TODO tester le contenu de certains champs


def test_formation_export(api_headers):
    """
    Route: /formation/formation_export/<int:formation_id>
    """
    r = requests.get(
        API_URL + "/formation/formation_export/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    export_formation = r.json()
    assert verify_fields(export_formation, FORMATION_FIELDS) is True
    # TODO tester le contenu de certains champs


# TODO
# def test_formsemestre_apo(api_headers):
#     r = requests.get(
#         API_URL + "/formation/apo/<string:etape_apo>",
#         headers=api_headers,
#         verify=CHECK_CERTIFICATE,
#     )
#     assert r.status_code == 200


def test_moduleimpl(api_headers):
    """
    Route: /formation/moduleimpl/<int:moduleimpl_id>
    """
    r = requests.get(
        API_URL + "/formation/moduleimpl/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    moduleimpl = r.json()
    assert verify_fields(moduleimpl, MODIMPL_FIELDS) is True
    # TODO tester le contenu de certains champs


def test_referentiel_competences(api_headers):
    """
    Route: "/formation/<int:formation_id>/referentiel_competences",
    """
    r = requests.get(
        API_URL + "/formation/1/referentiel_competences",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    # XXX A compléter
